@@ -433,12 +433,11 @@ class RedisRoot:
         for django_model, cache_conf in django_models_to_cache.items():
             cache_func = cache_conf['cache_func']
 
-            def django_field_to_redis_field(django_model, django_field):
+            def django_field_to_redis_field(django_model, django_field, redis_root):
 
-                def get_allowed_params(django_field):
-                    allowed_params = ['null', 'default', 'choices']
+                def get_allowed_params(django_field, django_model, redis_root):
+                    allowed_params = ['null', 'default', 'choices', 'model']
                     allowed_redis_params = {}
-                    print(django_field.__dict__)
                     for django_field_param_name in django_field.__dict__.keys():
                         if django_field_param_name in allowed_params:
                             value = getattr(django_field, django_field_param_name)
@@ -450,6 +449,8 @@ class RedisRoot:
                                 else:
                                     real_value = None
                                 value = real_value
+                            elif django_field_param_name == 'model':
+                                create_redis_model_from_django_model(django_model, redis_root)
                             allowed_redis_params[django_field_param_name] = value
                     return allowed_redis_params
 
@@ -476,7 +477,6 @@ class RedisRoot:
                     django_models.ManyToManyField: RedisManyToMany
                 }
 
-
                 if django_field.__class__.__name__.endswith('Rel'):
                     redis_field = None
                 elif django_field.__class__ in field_mapping.keys():
@@ -490,13 +490,13 @@ class RedisRoot:
                         (redis_field,),
                         {}
                     )
-                    redis_field = redis_field_class(**get_allowed_params(django_field))
+                    redis_field = redis_field_class(**get_allowed_params(django_field, django_model, redis_root))
                 return redis_field
 
             def create_redis_model_from_django_model(django_model, redis_root):
                 redis_fields = {}
                 for django_field in django_model._meta.get_fields():
-                    redis_field = django_field_to_redis_field(django_model, django_field)
+                    redis_field = django_field_to_redis_field(django_model, django_field, redis_root)
                     if redis_field:
                         django_field_name = django_field.name
                         if django_field_name in ['id', 'pk']:
